@@ -2,8 +2,8 @@ MISSING_STRING = '__missing__'
 AVAILABLE_LANGUAGES = ['en']
 
 REPORT_TRANSLATIONS ={
-    'Syncro performance report': {
-        'en': 'Syncro performance report'
+    'SYNCRO PERFORMANCE REPORT': {
+        'en': 'SYNCRO PERFORMANCE REPORT'
     },
 
     'Machine operation': {
@@ -74,17 +74,14 @@ REPORT_TRANSLATIONS ={
     'Time ON':{
          'en': 'Time ON'
     },
-    'Std cycle time':{
-         'en': 'Std cycle time'
+    'Std':{
+         'en': 'Standard'
     },
-    'Sync cycle time':{
-         'en': 'Sync cycle time'
+    'Sync':{
+         'en': 'Syncro'
     }, 
-    'KPI sync':{
-         'en': 'KPI sync'
-    },
-    'KPI std':{
-         'en': 'KPI std'
+    'Cycle time' : {
+        'en': 'Cycle time'
     },
     'Recipes':{
          'en': 'Recipes'
